@@ -45,14 +45,14 @@ if args.verbosity < len(LOG_LEVELS):
     logging.getLogger('apiclient.discovery').setLevel(logging.WARNING)
     logging.getLogger('oauth2client.util').setLevel(logging.ERROR)
 
-from gdrsync import binaryunit
-from gdrsync import driveutils
-from gdrsync import folder
-from gdrsync import localfolder
-from gdrsync import remotefolder
-from gdrsync import requestexecutor
-from gdrsync import utils
-from gdrsync import virtuallocalfolder
+from gdrsynclib import binaryunit
+from gdrsynclib import driveutils
+from gdrsynclib import folder
+from gdrsynclib import localfolder
+from gdrsynclib import remotefolder
+from gdrsynclib import requestexecutor
+from gdrsynclib import utils
+from gdrsynclib import virtuallocalfolder
 
 import apiclient.http
 import errno
